<?php
/**
 * Magpaper Pro: Color Patterns
 *
 * @package WordPress
 * @subpackage Magpaper Pro
 * @since 1.0
 */

/**
 * Generate the CSS for the current custom color scheme.
 */
function magpaper_pro_custom_colors_css() {
  	$options= magpaper_pro_get_theme_options();

	$color_value = $options['colorscheme_hue'];
	
	$css = '
	/*--------------------------------------------------------------
	# Background Color
	--------------------------------------------------------------*/
	.backtotop,
	input[type="submit"],
	#secondary .jetpack_subscription_widget input[type="submit"]:hover,
	#secondary .jetpack_subscription_widget input[type="submit"]:focus,
	.author-name:after,
	.reply a:hover:before,
	.reply a:focus:before,
	.site-info,
	.reply a,
	#respond input[type="submit"] {
	    background-color: ' . esc_attr( $color_value ) . ';
	}

	/*--------------------------------------------------------------
	# Text Color
	--------------------------------------------------------------*/
	a,
	.site-title a:hover,
	.site-title a:focus,
	.post-navigation a, 
	.posts-navigation a,
	.navigation.post-navigation a:hover,
	.navigation.posts-navigation a:hover,
	.navigation.post-navigation a:focus,
	.navigation.posts-navigation a:focus,
	input[type="submit"]:hover,
	input[type="submit"]:focus,
	.widget_popular_post h3 a:hover,
	.widget_popular_post h3 a:focus,
	.widget_popular_post a:hover time,
	.widget_popular_post a:focus time,
	.widget_latest_post h3 a:hover,
	.widget_latest_post h3 a:focus,
	.widget_latest_post a:hover time,
	.widget_latest_post a:focus time,
	.widget_featured_courses .course-wrapper h5 a:hover,
	.widget_featured_courses .course-wrapper h5 a:focus,
	.widget_featured_courses .tp-course-price,
	.widget_popular_courses .course-wrapper h5 a:hover,
	.widget_popular_courses .course-wrapper h5 a:focus,
	.widget_popular_courses .tp-course-price,
	.page-header small,
	.single-post-wrapper span.tags-links a:hover,
	.single-post-wrapper span.tags-links a:focus,
	.comment-metadata a:hover time,
	.comment-metadata a:focus time,
	.sticky-post-wrapper .read-more a:hover, 
	.sticky-post-wrapper .read-more a:focus,
	.single-wrapper .entry-meta span a:hover, 
	.single-wrapper .entry-meta span a:focus,
	.single-wrapper .cat-links a,
	.single-wrapper .entry-meta span.byline a.fn:hover,
	.single-wrapper .entry-meta span.byline a.fn:focus,
	.single-wrapper .entry-meta > span a:hover,
	.single-wrapper .entry-meta > span a:focus,
	#left-side-post .entry-title a:hover, 
	#right-side-post .entry-title a:hover, 
	#left-side-post .entry-title a:focus, 
	#right-side-post .entry-title a:focus,
	#hero-section .entry-title a:hover, 
	#hero-section .entry-title a:focus, 
	#featured-highlights-posts .entry-title a:hover, 
	#featured-highlights-posts .entry-title a:focus, 
	#featured-highlights-posts .entry-title a:hover b, 
	#featured-highlights-posts .entry-title a:focus b, 
	.entry-meta a:hover, .entry-meta a:focus, 
	#latest-posts .entry-title a:hover, 
	#latest-posts .entry-title a:focus, 
	#latest-posts .entry-title a:hover b, 
	#latest-posts .entry-title a:focus b,
	.main-navigation ul#primary-menu li.current-menu-item > a, 
	.main-navigation ul#primary-menu li:hover > a, 
	.main-navigation ul#primary-menu li:focus > a {
		color: ' . esc_attr( $color_value ) . ';
	}

	.main-navigation ul.nav-menu > li > a.search:hover svg.icon-search,
	.main-navigation ul.nav-menu > li > a.search:focus svg.icon-search,
	.main-navigation li.search-menu a:hover svg,
	.main-navigation li.search-menu a:focus svg,
	.main-navigation li.search-menu a.search-active svg,
	.navigation.post-navigation a:hover svg,
	.navigation.posts-navigation a:hover svg,
	.navigation.post-navigation a:focus svg,
	.navigation.posts-navigation a:focus svg,
	.single-post-wrapper span.posted-on svg,
	.single-post-wrapper span.cat-links svg,
	.archive-blog-wrapper .posted-on svg,
	.sticky-post-wrapper .posted-on svg,
	.sticky-post-wrapper .read-more a svg,
	#top-bar .social-menu a:hover svg,
	.main-navigation ul#primary-menu li:hover > svg, 
	.main-navigation ul#primary-menu li:focus > svg, 
	.main-navigation li.menu-item-has-children:hover > a > svg, 
	.main-navigation li.menu-item-has-children > a:hover > svg, 
	.main-navigation li.menu-item-has-children > a:focus > svg, 
	.main-navigation ul#primary-menu > li.current-menu-item > a > svg,
	.read-more a svg {
		fill: ' . esc_attr( $color_value ) . ';
	}

	/*--------------------------------------------------------------
	# Border Color
	--------------------------------------------------------------*/
	input[type="submit"],
	.single-post-wrapper span.tags-links a:hover,
	.single-post-wrapper span.tags-links a:focus,
	.sticky-post-wrapper .read-more a svg {
	    border-color: ' . esc_attr( $color_value ) . ';
	}

	.site-title a {
	    border-bottom-color: ' . esc_attr( $color_value ) . ';
	}

	/*--------------------------------------------------------------
	# Responsive
	--------------------------------------------------------------*/
	@media screen and (min-width: 1024px) {
		.main-navigation ul.sub-menu li:hover > a,
		.main-navigation ul.sub-menu li:focus > a {
			background-color: ' . esc_attr( $color_value ) . ';
			color: #fff;
		}
		.main-navigation ul ul {
		    border-top-color: ' . esc_attr( $color_value ) . ';
		}
		.main-navigation ul.nav-menu > li.menu-item-has-children:hover > a:after {
			border-bottom-color: ' . esc_attr( $color_value ) . ';
		}
	}

	@keyframes defaultpreloader {
	    0% {height:5px;transform:translateY(0px);background: ' . esc_attr( $color_value ) . ';}
	    25% {height:30px;transform:translateY(15px);background: ' . esc_attr( $color_value ) . ';}
	    50% {height:5px;transform:translateY(0px);background: ' . esc_attr( $color_value ) . ';}
	    100% {height:5px;transform:translateY(0px);background: ' . esc_attr( $color_value ) . ';}
	}
	';

	/**
	 * Filters Magpaper Pro custom colors CSS.
	 *
	 * @since Magpaper Pro 1.0.0
	 *
	 * @param string $css        Base theme colors CSS.
	 */
	return apply_filters( 'magpaper_pro_custom_colors_css', $css );
}
